@@ -43,30 +43,27 @@ from simmate.calculators.vasp.error_handlers import (
 
 class MITRelaxation(VaspTask):
     """
-    Runs a VASP geometry optimization using MIT Project settings.
+    This task is a reimplementation of pymatgen's
+    [MITRelaxSet](https://pymatgen.org/pymatgen.io.vasp.sets.html#pymatgen.io.vasp.sets.MITRelaxSet).
 
-    The MIT Project is the precursor to the Materials Project.
+    Runs a VASP geometry optimization using MIT Project settings, where the
+    MIT Project is the precursor to the Materials Project.
 
     From their documention in pymatgen:
-
-        "Default VASP settings for calculations in the pre-cursor MIT project to
-        the Materials Project. Reasonably robust, but selected PSP are generally the
-        ones with fewer electrons and convergence criteria is less tight. This was
-        used in an era whether computational power is more limited.
-        Nevertheless, this is still a good starting point for extremely expensive
-        methods."
-
+    ```
+    Default VASP settings for calculations in the pre-cursor MIT project to
+    the Materials Project. Reasonably robust, but selected PSP are generally the
+    ones with fewer electrons and convergence criteria is less tight. This was
+    used in an era whether computational power is more limited.
+    Nevertheless, this is still a good starting point for extremely expensive
+    methods.
+    ```
     """
 
-    # This uses the PBE functional with POTCARs that have lower electron counts
-    # and convergence criteria.
     functional = "PBE"
     potcar_mappings = PBE_ELEMENT_MAPPINGS_LOW_QUALITY
 
-    # These are all input settings for this task. Note a lot of settings
-    # depend on the structure/composition being analyzed.
     incar = dict(
-        # These settings are the same for all structures regardless of composition
         ALGO="Fast",
         EDIFF=1.0e-05,
         ENCUT=520,
@@ -82,11 +79,11 @@ class MITRelaxation(VaspTask):
         NELMIN=6,
         NSW=99,
         PREC="Accurate",
+        ISMEAR=-5,
+        SIGMA=0.05,
         KSPACING=0.5,  # !!! This is where we are different from pymatgen right now
-        # The magnetic moments are dependent on what the composition and oxidation
-        # states are. Note our default of 0.6 is different from the VASP default too.
         MAGMOM__smart_magmom={
-            "default": 0.6,
+            "default": 0.6,  # note this is different from the VASP default
             "Ce": 5,
             "Ce3+": 1,
             "Co": 0.6,
@@ -118,25 +115,7 @@ class MITRelaxation(VaspTask):
             "W": 5,
             "Yb3+": 1,
         },
-        # The type of smearing we use depends on if we have a metal, semiconductor,
-        # or insulator. So we need to decide this using a keyword modifier.
-        multiple_keywords__smart_ismear={
-            "metal": dict(
-                ISMEAR=2,
-                SIGMA=0.2,
-            ),
-            "non-metal": dict(
-                ISMEAR=-5,
-                SIGMA=0.05,
-            ),
-        },
-        # Changing limits of mixing for larger atoms
         LMAXMIX__smart_lmaxmix=True,
-        # We run LDA+U for certain compositions. This is a complex configuration
-        # so be sure to read the "__smart_ldau" modifier for more information.
-        # But as an example for how the mappings work...
-        # {"F": {"Ag": 2}} means if the structure is a fluoride, then we set
-        # the MAGMOM for Ag to 2. Any element that isn't listed defaults to 0.
         multiple_keywords__smart_ldau=dict(
             LDAU__auto=True,
             LDAUTYPE=2,
@@ -217,7 +196,6 @@ class MITRelaxation(VaspTask):
         ),
     )
 
-    # These are some default error handlers to use
     error_handlers = [
         TetrahedronMesh(),
         RotationMatrix(),
