@@ -15,17 +15,17 @@ from simmate.calculators.vasp.database.population_analysis import (
 )
 from simmate.calculators.bader.tasks import BaderAnalysis as BaderAnalysisTask
 
-prebader_workflow = s3task_to_workflow(
+prebader_matproj_workflow = s3task_to_workflow(
     name="population-analysis/prebader-matproj",
     module=__name__,
     project_name="Simmate-PopulationAnalysis",
     s3task=MPPreBaderTask,
-    calculation_table=MPBaderResults,
-    register_kwargs=["prefect_flow_run_id", "structure", "source"],
+    database_table=MPBaderResults,
+    register_kwargs=["structure", "source"],
     description_doc_short="uses Materials Project settings with denser FFT grid",
 )
 
-prebader_task = prebader_workflow.to_workflow_task()
+prebader_task = prebader_matproj_workflow.to_workflow_task()
 
 
 @task
@@ -74,9 +74,8 @@ with Workflow("population-analysis/bader-matproj") as workflow:
 
 workflow.storage = ModuleStorage(__name__)
 workflow.project_name = "Simmate-PopulationAnalysis"
-workflow.calculation_table = MPBaderResults
-workflow.result_table = MPBaderResults
-workflow.register_kwargs = ["prefect_flow_run_id", "structure", "source"]
+workflow.database_table = MPBaderResults
+workflow.register_kwargs = ["structure", "source"]
 workflow.result_task = bader_result
 workflow.s3tasks = [MPPreBaderTask, BaderAnalysisTask]
 
