@@ -13,7 +13,7 @@ workflow = s3task_to_workflow(
     module=__name__,
     project_name="Simmate-Energy",
     s3task=Quality04EnergyTask,
-    calculation_table=Quality04StaticEnergyResults,
-    register_kwargs=["prefect_flow_run_id", "structure", "source"],
+    database_table=Quality04StaticEnergyResults,
+    register_kwargs=["structure", "source"],
     description_doc_short="low-quality settings meant for highly unreasonable structures",
 )
