@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-import click
+from typing import List
 
-from typing import List, Union
+import click
 from click import Context
 
 
@@ -55,17 +55,11 @@ def list_options(options: List) -> int:
     return selected_index
 
 
-def parse_parameters(
-    context: Context,
-    structure: str = None,
-    command: str = None,
-    directory: str = None,
-) -> dict:
+def parse_parameters(context: Context) -> dict:
     """
     This is a utility for click (cli) that formats input parameters for workflow
-    runs. It is a small wrapper around
-    `simmate.workflow_engine.utilities.parse_parameters` that accounts for
-    recieving a `click.Context` object.
+    runs. It accounts for recieving a `click.Context` object and ensures we
+    return a dictionary.
 
     In order to provide a context, make sure the click command has the following:
 
@@ -86,8 +80,6 @@ def parse_parameters(
     This is also why we have pass_context and then the kwarg context.
     """
 
-    from simmate.workflows.utilities import parse_parameters
-
     # The extra keywords passed are given as a list such as...
     #   ["--arg1", "val1", "--arg2", "val2",]
     # Using code from stack overflow, we parse that data into a dictionary.
@@ -98,9 +90,6 @@ def parse_parameters(
             context.args[i][2:]: context.args[i + 1]
             for i in range(0, len(context.args), 2)
         }
-        kwargs_cleaned["structure"] = structure
-        kwargs_cleaned["directory"] = directory
-        kwargs_cleaned["command"] = command
 
     except:
         raise click.ClickException(
@@ -109,10 +98,6 @@ def parse_parameters(
             "keyword and the value (such as `--example_kwarg example_value`)."
         )
 
-    # We can now pass this dictionary to our normal parse_parameters utility
-    # that will convert everything to python objects for us.
-    kwargs_cleaned = parse_parameters(**kwargs_cleaned)
-
     return kwargs_cleaned
 
 
@@ -267,27 +252,8 @@ def setup_only(workflow_name, filename, directory):
     )
 )
 @click.argument("workflow_name")
-@click.option(
-    "--structure",
-    "-s",
-    default=None,
-    type=click.Path(exists=True),
-    help="filename of the structure used for this workflow (note, not all workflows use this arg)",
-)
-@click.option(
-    "--command",
-    "-c",
-    default=None,
-    help="the command used to call call the calculator (e.g. 'mpirun -n 12 vasp_std > vasp.out')",
-)
-@click.option(
-    "--directory",
-    "-d",
-    default=None,
-    help="the folder to run this workflow in. Defaults to simmate-task-12345, where 12345 is randomized",
-)
 @click.pass_context
-def run(context, workflow_name, structure, command, directory):
+def run(context, workflow_name):
     """Runs a workflow using provided parameters"""
 
     click.echo("LOADING WORKFLOW & INPUT PARAMETERS...")
@@ -299,22 +265,15 @@ def run(context, workflow_name, structure, command, directory):
         precheck_flow_exists=True,
         print_equivalent_import=True,
     )
-    kwargs_cleaned = parse_parameters(
-        context=context,
-        structure=structure,
-        command=command,
-        directory=directory,
-    )
+    kwargs_cleaned = parse_parameters(context=context)
 
     click.echo("RUNNING WORKFLOW...")
 
     result = workflow.run(**kwargs_cleaned)
 
     # Let the user know everything succeeded
-    # if result.is_successful():
-    #     click.echo("Success! All results are also stored in your database.")
-    # BUG: we remove this temporarily because we have s3tasks ran through this
-    # module. When we add their database components, this will be removed.
+    if result.is_successful():
+        click.echo("Success! All results are also stored in your database.")
 
 
 @workflows.command(
@@ -324,27 +283,8 @@ def run(context, workflow_name, structure, command, directory):
     )
 )
 @click.argument("workflow_name")
-@click.option(
-    "--structure",
-    "-s",
-    default=None,
-    type=click.Path(exists=True),
-    help="filename of the structure used for this workflow (note, not all workflows use this arg)",
-)
-@click.option(
-    "--command",
-    "-c",
-    default=None,
-    help="the command used to call call the calculator (e.g. 'mpirun -n 12 vasp_std > vasp.out')",
-)
-@click.option(
-    "--directory",
-    "-d",
-    default=None,
-    help="the folder to run this workflow in. Defaults to simmate-task-12345, where 12345 is randomized",
-)
 @click.pass_context
-def run_cloud(context, workflow_name, structure, command, directory):
+def run_cloud(context, workflow_name):
     """Submits a workflow to Prefect cloud"""
 
     click.echo("LOADING WORKFLOW & INPUT PARAMETERS...")
@@ -356,12 +296,7 @@ def run_cloud(context, workflow_name, structure, command, directory):
         precheck_flow_exists=True,
         print_equivalent_import=True,
     )
-    kwargs_cleaned = parse_parameters(
-        context=context,
-        structure=structure,
-        command=command,
-        directory=directory,
-    )
+    kwargs_cleaned = parse_parameters(context=context)
 
     click.echo("RUNNING WORKFLOW...")
 
@@ -387,21 +322,50 @@ def run_yaml(filename):
     import yaml
 
     with open(filename) as file:
-        kwargs = yaml.full_load(file)
+        parameters = yaml.full_load(file)  # this is updated below
 
-    # we pop the workflow name so that it is also removed from the rest of kwargs
-    from simmate.workflows.utilities import get_workflow, parse_parameters
+    from simmate.workflows.utilities import get_workflow
 
     workflow = get_workflow(
-        workflow_name=kwargs.pop("workflow_name"),
+        # we pop the workflow name so that it is also removed from the rest of kwargs
+        workflow_name=parameters.pop("workflow_name"),
         precheck_flow_exists=True,
         print_equivalent_import=True,
     )
-    kwargs_cleaned = parse_parameters(**kwargs)
+
+    # -------------------------------------------------------------------------
+
+    # SPECIAL CASE -- Running customized workflows from yaml.
+    # !!! When prefect 2.0 is available, I will be able to use **kwargs as an
+    # input for workflow parameters -- in which case, I can move this functionality
+    # to load_input_and_register.
+
+    # For customized workflows, we need to completely change the format
+    # that we provide the parameters. Customized workflows expect parameters
+    # broken into a dictionary of
+    #   {"workflow_base": ..., "input_parameters":..., "updated_settings": ...}
+    if "workflow_base" in parameters.keys():
+
+        parameters["input_parameters"] = {}
+        parameters["updated_settings"] = {}
+
+        for key, update_values in list(parameters.items()):
+            # Skip the base keys
+            if key in ["workflow_base", "input_parameters", "updated_settings"]:
+                continue
+            # if there is no prefix, then we have a normal input parameter
+            elif not key.startswith("custom__"):
+                parameters["input_parameters"][key] = parameters.pop(key)
+            # Otherwise remove the prefix and add it to the custom settings.
+            else:
+                key_cleaned = key.removeprefix("custom__")
+                parameters["updated_settings"][key_cleaned] = parameters.pop(key)
+
+    # -------------------------------------------------------------------------
 
     click.echo("RUNNING WORKFLOW...")
 
-    result = workflow.run(**kwargs_cleaned)
+    result = workflow.run(**parameters)
 
     # Let the user know everything succeeded
     if result.is_successful():
