@@ -3,6 +3,7 @@
 import json
 import cloudpickle
 import yaml
+from typing import List
 
 # note: extra modules are imported from prefect for convenience imports elsewhere
 import prefect
@@ -16,9 +17,8 @@ from prefect.backend import FlowRunView, FlowView
 # in order to support "mocking" this function in unit tests
 from prefect.backend import flow_run as flow_run_module
 
-from typing import List
-from simmate.workflow_engine.supervised_staged_shell_task import S3Task
-from simmate.database.base_data_types import DatabaseTable, Calculation
+from simmate.database.base_data_types import Calculation
+from simmate.workflow_engine import S3Task
 
 
 class Workflow(PrefectFlow):
@@ -28,7 +28,8 @@ class Workflow(PrefectFlow):
     method, which allows us to register a calculation to a database table before
     we submit the workflow to Prefect Cloud.
 
-    To learn how to use this class, see [prefect.core.flow.Flow](https://docs.prefect.io/api/latest/core/flow.html#flow-2)
+    To learn how to use this class, see
+    [prefect.core.flow.Flow](https://docs.prefect.io/api/latest/core/flow.html#flow-2)
     """
 
     result_task: Task = None
@@ -41,8 +42,8 @@ class Workflow(PrefectFlow):
 
     project_name: str = None
     """
-    The name of the project in the  that this workflow is associated with. This 
-    attribute is mainly just for organizing workflows in the Prefect Cloud interface.
+    The name of the project in Prefect Cloud that this workflow is associated with. This 
+    attribute is mainly just for organizing workflows in the web interface.
     """
 
     s3task: S3Task = None
@@ -53,23 +54,14 @@ class Workflow(PrefectFlow):
     without storing results in the database.
     """
 
-    calculation_table: Calculation = None
+    database_table: Calculation = None
     """
     The database table where calculation information (such as the prefect_flow_run_id)
-    is stored. Note, for NestedWorkflows, this table will not be the same as the
-    result table! The table should use 
-    `simmate.database.base_data_types.Calculation`
-    """
-
-    result_table: DatabaseTable = None
-    """
-    The database table where all calculation results are stored. In many cases,
-    this is the same table as `calculation_table` -- the exception is
-    for NestedWorkflows, where the result table may point to a specific
-    sub-workflow's table for results. An example of this is the relaxation/staged
-    workflow, which is made up of a series of relaxations -- and the result 
-    table points to the final relaxation in this series. The table should use 
-    `simmate.database.base_data_types.DatabaseTable`
+    is stored. The table should use `simmate.database.base_data_types.Calculation`
+    
+    In many cases, this table will contain all of the results you need. However,
+    pay special attention to NestedWorkflows, where your results are often tied
+    to a final task.
     """
 
     description_doc_short: str = None
@@ -78,6 +70,12 @@ class Workflow(PrefectFlow):
     in the list-view of all different workflow presets.
     """
 
+    register_kwargs: List[str] = []
+    """
+    (experimental feature)
+    A list of input parameters that should be used to register the calculation.
+    """
+
     @property
     def type(self) -> str:
         """
@@ -174,8 +172,14 @@ class Workflow(PrefectFlow):
             project_name=self.project_name,
         )
 
-        # Serialize all of the parameters so they can be properly submitted
-        parameters_serialized = self._serialize_parameters(kwargs)
+        # Prefect does not properly deserialize objects that have
+        # as as_dict or to_dict method, so we use a custom method to do that here
+        parameters_serialized = self._serialize_parameters(**kwargs)
+        # BUG: What if we are submitting using a filename? We don't want to
+        # submit to a cluster and have the job fail because it doesn't have
+        # access to the file. One solution could be to deserialize right before
+        # serializing in the next line in order to ensure parameters that
+        # accept file names are submitted with all necessary data.
 
         # Now we submit the workflow
         logger.info(f"Creating flow run for {self.name}...") if logger else None
@@ -187,7 +191,7 @@ class Workflow(PrefectFlow):
         )
 
         # we log the website url to the flow for the user
-        run_url = client.get_cloud_url("flow-run", flow_run_id, as_user=False)
+        run_url = client.get_cloud_url("flow-run", flow_run_id)
         logger.info(f"Created flow run: {run_url}") if logger else None
 
         # -----------------------------------
@@ -197,39 +201,18 @@ class Workflow(PrefectFlow):
         # submitted.
         # BUG: Will there be a race condition here? What if the workflow finishes
         # and tries writing to the databse before this is done?
-        register_kwargs = {
-            key: kwargs[key] for key in kwargs if key in self.register_kwargs
-        }
-        calc = self._register_calculation(
-            flow_run_id,
-            **register_kwargs,
-        )  # !!! should I return the calc to the user?
+        parameters_cleaned = self._deserialize_parameters(**kwargs)
+        self._register_calculation(flow_run_id, parameters_cleaned)
         # -----------------------------------
 
         # if we want to wait until the job is complete, we do that here
         if wait_for_run:
             flow_run_view = self.wait_for_flow_run(flow_run_id)
             # return flow_run_view # !!! Should I return this instead?
+
         # return the flow_run_id for the user
         return flow_run_id
 
-    def _register_calculation(self, flow_run_id: str, **kwargs):
-        """
-        If the workflow is linked to a calculation table in the Simmate database,
-        this adds the flow run to the Simmate database.
-
-        This method should not be called directly as it is used within the
-        run_cloud() method.
-        """
-        # If there's no calculation database table in Simmate for this workflow,
-        # just skip this step. Otherwise save/load the calculation to our table
-        if self.calculation_table:
-            calculation = self.calculation_table.from_prefect_id(
-                id=flow_run_id,
-                **kwargs,
-            )
-            return calculation
-
     def wait_for_flow_run(self, flow_run_id: str):
         """
         Waits for a given flow run to complete
@@ -245,11 +228,43 @@ class Workflow(PrefectFlow):
         for log in flow_run_module.watch_flow_run(flow_run_id):
             message = f"Flow {flow_run.name}: {log.message}"
             prefect.context.logger.log(log.level, message)
+
         # Return the final view of the flow run
         return flow_run.get_latest()
 
+    def _register_calculation(self, prefect_flow_run_id, parameters):
+        """
+        If the workflow is linked to a calculation table in the Simmate database,
+        this adds the flow run to the database.
+
+        Parameters passed should be deserialized and cleaned.
+
+        This method should not be called directly as it is used within the
+        `run_cloud` method and `load_input_and_register` task.
+        """
+
+        # grab the registration kwargs from the parameters provided
+        register_kwargs = {
+            key: parameters.get(key, None) for key in self.register_kwargs
+        }
+
+        # SPECIAL CASE: for customized workflows we need to convert the inputs
+        # back to json before saving to the database.
+        if "workflow_base" in parameters:
+            parameters_serialized = self._serialize_parameters(**parameters)
+            calculation = self.database_table.from_prefect_id(
+                id=prefect_flow_run_id,
+                **parameters_serialized,
+            )
+        else:
+            # load/create the calculation for this workflow run
+            calculation = self.database_table.from_prefect_id(
+                id=prefect_flow_run_id,
+                **register_kwargs,
+            )
+
     @staticmethod
-    def _serialize_parameters(parameters: dict) -> dict:
+    def _serialize_parameters(**parameters) -> dict:
         """
         Converts input parameters to json-sealiziable objects that Prefect can
         use.
@@ -257,6 +272,8 @@ class Workflow(PrefectFlow):
         This method should not be called directly as it is used within the
         run_cloud() method.
         """
+        # TODO: consider moving this into prefect's core code as a contribution.
+
         # Because many flows allow object-type inputs (such as structure object),
         # we need to serialize these inputs before scheduling them with prefect
         # cloud. To do this, I only check for two potential methods:
@@ -279,11 +296,97 @@ class Workflow(PrefectFlow):
                     parameter_value = parameter_value.as_dict()
                 elif hasattr(parameter_value, "to_dict"):
                     parameter_value = parameter_value.to_dict()
+
+                # workflow_base and input_parameters are special cases that
+                # may require a refactor (for customized workflows)
+                elif parameter_key == "workflow_base":
+                    parameter_value = parameter_value.name
+                elif parameter_key == "input_parameters":
+                    # recursive call to this function
+                    parameter_value = Workflow._serialize_parameters(**parameter_value)
+
                 else:
                     parameter_value = cloudpickle.dumps(parameter_value)
             parameters_serialized[parameter_key] = parameter_value
         return parameters_serialized
 
+    @staticmethod
+    def _deserialize_parameters(**parameters) -> dict:
+        """
+        converts all parameters to appropriate python objects
+        """
+
+        # we don't want to pass arguments like command=None or structure=None if the
+        # user didn't provide this input parameter. Instead, we want the workflow to
+        # use its own default value. To do this, we first check if the parameter
+        # is set in our kwargs dictionary and making sure the value is NOT None.
+        # If it is None, then we remove it from our final list of kwargs. This
+        # is only done for command, directory, and structure inputs -- as these
+        # are the three that are typically assumed to be present (see the CLI).
+
+        from simmate.toolkit import Structure
+        from simmate.toolkit.diffusion import MigrationHop, MigrationImages
+
+        parameters_cleaned = parameters.copy()
+
+        #######
+        # SPECIAL CASE: customized workflows have their parameters stored under
+        # "input_parameters" instead of the base dict
+        # THIS INVOLVES A RECURSIVE CALL TO THIS SAME METHOD
+        if "workflow_base" in parameters.keys():
+            # This is a non-modular import that can cause issues and slower
+            # run times. We therefore import lazily.
+            from simmate.workflows.utilities import get_workflow
+
+            parameters_cleaned["workflow_base"] = get_workflow(
+                parameters["workflow_base"]
+            )
+            parameters_cleaned["input_parameters"] = Workflow._deserialize_parameters(
+                **parameters["input_parameters"]
+            )
+            return parameters_cleaned
+        #######
+
+        if not parameters.get("command", None):
+            parameters_cleaned.pop("command", None)
+
+        if not parameters.get("directory", None):
+            parameters_cleaned.pop("directory", None)
+
+        structure = parameters.get("structure", None)
+        if structure:
+            parameters_cleaned["structure"] = Structure.from_dynamic(structure)
+        else:
+            parameters_cleaned.pop("structure", None)
+
+        if "structures" in parameters.keys():
+            structure_filenames = parameters["structures"].split(";")
+            parameters_cleaned["structures"] = [
+                Structure.from_dynamic(file) for file in structure_filenames
+            ]
+
+        if "migration_hop" in parameters.keys():
+            migration_hop = MigrationHop.from_dynamic(parameters["migration_hop"])
+            parameters_cleaned["migration_hop"] = migration_hop
+
+        if "migration_images" in parameters.keys():
+            migration_images = MigrationImages.from_dynamic(
+                parameters["migration_images"]
+            )
+            parameters_cleaned["migration_images"] = migration_images
+
+        if "supercell_start" in parameters.keys():
+            parameters_cleaned["supercell_start"] = Structure.from_dynamic(
+                parameters["supercell_start"]
+            )
+
+        if "supercell_end" in parameters.keys():
+            parameters_cleaned["supercell_end"] = Structure.from_dynamic(
+                parameters["supercell_end"]
+            )
+
+        return parameters_cleaned
+
     @property
     def nflows_submitted(self) -> int:
         """
