@@ -9,4 +9,7 @@ Workflows for predicting oxidation states within a material
 from simmate.calculators.vasp.workflows.population_analysis import (
     bader_matproj_workflow,
     elf_matproj_workflow,
+    badelf_matproj_workflow,
+    prebader_matproj_workflow,
+    prebadelf_matproj_workflow,
 )
